Lua_ChaosCopyBlessingWindow = class("Lua_ChaosCopyBlessingWindow", Lua_Window)
function Lua_ChaosCopyBlessingWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ChaosCopyBlessingWindow";
	self.skinName = "ChaosCopyBlessingWindow_skin";
	self.showBlackMask = true;
end

function Lua_ChaosCopyBlessingWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.itemList = Array();

	self.btnSubmit:setEnable(false);
	self.btnSubmit:addClickFuntion(self, self.onSubmitClick);

	self:addLuaEvent("CHAOS_COPY_BLESSIMG_SELECT", self, self.onBlessingSelected);
	self:updateShowInfo();
end

function Lua_ChaosCopyBlessingWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList:clear();
		self.itemList = nil;
	end
	if self.showData ~= nil then
		DataCenter.fightData:showFightResult(self.showData, nil, nil, true);
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChaosCopyBlessingWindow:updateShowInfo()
	local list = DataCenter.chaosCopyData.blessingList;
	local dataLen = list and #list or 0;
	local len = self.itemList:getSize();
	local maxLen = dataLen > len and dataLen or len;
	local item;
	for i = 1 , maxLen do
		item = self.itemList[i];
		if i > dataLen then
			if item then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_ChaosCopyBlessingItem.new(self.content);
				self.itemList:add(item);
			else
				item:setEnable(true);
			end
			item:setLocation(-217 + (i - 1) * 217, 60, 0);
			item:setData(list[i]);
		end
	end
end

function Lua_ChaosCopyBlessingWindow:onBlessingSelected(data)
	self.btnSubmit:setEnable(true);
	self.data = data;

	local item;
	for i = 1, self.itemList:getSize() do
		item = self.itemList[i];
		item:setSelected(item.data == data);
		item:setMask(not (item.data == data));
	end
end

function Lua_ChaosCopyBlessingWindow:onSubmitClick(go)
	if self.data == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ChaosCopyProxy"):sBlessingSelect(self.data);
	DataCenter.chaosCopyData.blessingList = nil;
	self:hide();
end










Lua_ChaosCopyBlessingItem = class("Lua_ChaosCopyBlessingItem", Lua_DisplayObject)
function Lua_ChaosCopyBlessingItem:ctor(p)
	self:superCall("ctor", p, "ChaosCopyBlessingItem_skin");
end

function Lua_ChaosCopyBlessingItem:buildShowItem()
	self:superCall("buildShowItem");

	self.bg.clickScale = false;
	self.bg:addClickFuntion(self, self.onClick);
	self:setSelected(false);
end

function Lua_ChaosCopyBlessingItem:dispose()
	TweenUtil.getInstance():stop(self.content);
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChaosCopyBlessingItem:setData(data)
	self.data = tonumber(data);

	local config = DataCenter.chaosCopyUtil:getBlessingConfig(self.data);
	self.bg:setUrl("/images/expedition/ui_bjyz_window_00"..(config.color - 2)..".png");

	if config.color == 5 then
		self.nameText.colorStr = Lua_ColorDefine.transColorStr("DE6D29");
	elseif config.color == 4 then
		self.nameText.colorStr = Lua_ColorDefine.transColorStr("C616B7");
	else
		self.nameText.colorStr = Lua_ColorDefine.transColorStr("159EC5");
	end
	self.nameText.text = config.name;

	config = Lua_SkillConfigData.getConfigData(config.skill_id);
	self.skillIcon:setAltas(config.atlas, config.sprite);
	self.desText.text = config.des;
end

function Lua_ChaosCopyBlessingItem:setSelected(bSelected)
	TweenUtil.getInstance():stop(self.content);
	if bSelected then
		self:setScale(1, 1, 1);
		TweenUtil.getInstance():addTweenTargetScale(self.content, 0.1, 0, 1.05, 1.05, 1.05);
		TweenUtil.getInstance():addTweenTargetScale(self.content, 0.1, 0.1, 0.9, 0.9, 0.9);
		TweenUtil.getInstance():addTweenTargetScale(self.content, 0.1, 0.2, 1, 1, 1);
	else
		self:setScale(0.9, 0.9, 1);
	end
end

function Lua_ChaosCopyBlessingItem:setMask(bValue)
	if bValue then
		if self.maskBg == nil then
			self.maskBg = UICreate.createUIAtlasImage(self.content, "expedition_atlas_2", "ui_bjyz_window_018", 0, -10, 200, 463);
			self.maskBg:setScale(1.09, 1.09, 1);
		end
		self.maskBg:setEnable(true);
	else
		if self.maskBg then
			self.maskBg:setEnable(false);
		end
	end
end

function Lua_ChaosCopyBlessingItem:onClick(go)
	Lua_MsgUtil.callFunc("CHAOS_COPY_BLESSIMG_SELECT", self.data);
end