Lua_ChaosCopyStageItem = class("Lua_ChaosCopyStageItem", Lua_DisplayObject)
function Lua_ChaosCopyStageItem:ctor(p)
	self:superCall("ctor", p, "ChaosCopyStageItem_skin");
end

function Lua_ChaosCopyStageItem:buildShowItem()
	self:superCall("buildShowItem");
	self.tranEff = UICreate.createUIEffect(self.content, nil, nil, 0, -75);
	self.tranEff.siblingIndex = 5;
	self.tranEff:setEnable(false);

	self.bgEff = UICreate.createUIEffect(self.content, nil, nil, 0, -75);
	self.bgEff.siblingIndex = 6;
	self.bgEff:setEnable(false);

	self.boxIcon:addClickFuntion(self, self.onPreViewReward);
	self.btnFight:addClickFuntion(self, self.onFightClick);
end

function Lua_ChaosCopyStageItem:dispose()
	Lua_CommonUtil.removeTimer(self, self.showEffect);
	if self.tranEff then
		self.tranEff:dispose();
		self.tranEff = nil;
	end
	if self.bgEff then
		self.bgEff:dispose();
		self.bgEff = nil;
	end
	self:superCall("dispose");
end

function Lua_ChaosCopyStageItem:setData()
	self.stageId = DataCenter.chaosCopyData.curStageId;
	local config = DataCenter.chaosCopyUtil:getStageConfig(self.stageId);
	self.nameText.text = config.stage_name;

	local day = config.open_day - DataCenter.roleData.open_days;
	if day > 0 then
		self.isLock = true;
		self.lockObject:SetActive(true);
		self.lockText.text = LanUtil.formateStr(796008, tostring(day));
	else
		self.isLock = false;
		self.lockObject:SetActive(false);
	end

	local blessingList = DataCenter.chaosCopyData.blessingList;
	if blessingList and #blessingList > 0 then
		self.effType = 1;
		self.tipsBg:setEnable(true);
		self.tipsIcon:setEnable(true);
		self.tipsIcon:setAltas("chaos_copy_atlas", "xui_hdxj_title_02");
	elseif DataCenter.chaosCopyData.hasExtraReward then
		self.effType = 2;
		self.tipsBg:setEnable(true);
		self.tipsIcon:setEnable(true);
		self.tipsIcon:setAltas("chaos_copy_atlas", "xui_hdxj_title_03");
	else
		self.effType = 0;
		self.tipsBg:setEnable(false);
		self.tipsIcon:setEnable(false);
	end

	local difficulty = DataCenter.chaosCopyData.difficulty;
	if difficulty > 0 then
		self.difficultyText:setEnable(true);
		self.difficultyText.text = LanUtil.formateStr(796007, tostring(difficulty));
	else
		self.difficultyText:setEnable(false);
	end
end

function Lua_ChaosCopyStageItem:playEffect(bEnter)
	Lua_CommonUtil.removeTimer(self, self.showEffect);
	if bEnter and not self.isLock then
		self.bgEff:setEnable(false);
		if self.effType == 1 then
			self.tranEff:setUrl("/effects/uiEffects/ui_hdxj_m03", "ui_hdxj_m03_1");
		elseif self.effType == 2 then
			self.tranEff:setUrl("/effects/uiEffects/ui_hdxj_m02", "ui_hdxj_m02_1");
		else
			self.tranEff:setUrl("/effects/uiEffects/ui_hdxj_m01", "ui_hdxj_m01_1");
		end
		self.tranEff:setEnable(false);
		self.tranEff:setEnable(true);
		Lua_CommonUtil.delayCall(0.3, self, self.showEffect);
	else
		self:showEffect();
	end
end

function Lua_ChaosCopyStageItem:showEffect()
	if self.effType == 1 then
		self.bgEff:setUrl("/effects/uiEffects/ui_hdxj_m03", "ui_hdxj_m03");
	elseif self.effType == 2 then
		self.bgEff:setUrl("/effects/uiEffects/ui_hdxj_m02", "ui_hdxj_m02");
	else
		self.bgEff:setUrl("/effects/uiEffects/ui_hdxj_m01", "ui_hdxj_m01");
	end
	self.bgEff:setEnable(not self.isLock);
end

function Lua_ChaosCopyStageItem:onPreViewReward(go)
	Lua_WindowUtil.openWin("Lua_ChaosCopyPreViewRewardWindow", Lua_WinParam.ACTION_OPEN, self.stageId);
end

function Lua_ChaosCopyStageItem:onFightClick(go)
	if DataCenter.chaosCopyData.isAllPass then
		OperateAlert.showLangValue(796003);
		return;
	end

	if DataCenter.chaosCopyData.seasonStatus == 2 then
		OperateAlert.showLangValue(796021);
		return;
	end

	local blessingList = DataCenter.chaosCopyData.blessingList;
	if blessingList and #blessingList > 0 then
		OperateAlert.showLangValue(796004);
		Lua_WindowUtil.openWin("Lua_ChaosCopyBlessingWindow", Lua_WinParam.ACTION_OPEN);
		return;
	end

	Lua_MsgUtil.callFunc("CHAOS_COPY_FIGHT", self.stageId);
end