-- 混沌玄境
checkRequire("Lua_ChaosCopyStageItem");
Lua_ChaosCopyWindow = class("Lua_ChaosCopyWindow", Lua_Window)
function Lua_ChaosCopyWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_ChaosCopyWindow";
	self.skinName = "ChaosCopyWindow_skin";
	self.isFullSizeWin = true;
	-- self.isSingleShowWin = true;
	self.showWinBg = true;
	self.winBgPath = "/images/chaos_copy/xui_hdxj_bg_01.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_ChaosCopyWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.winBg.anchorValue = 4;
	self.winBg.pivotValue = 4;
	
	self.chapterArr = Array();
	self.taskRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.ChaosCopy_Task);
	self.taskRedPoint:setRectAnchor(7);
	self.taskRedPoint:setLocation(115, 75, 0);

	self.btnHelp:addClickFuntion(self, self.onHelpClick);
	self.hookBox:addClickFuntion(self, self.onHookReceive);
	self.btnShop:addClickFuntion(self, self.onShopClick);
	self.btnSwords:addClickFuntion(self, self.onSwordsClick);
	self.btnTask:addClickFuntion(self, self.onTaskClick);
	self.btnWar:addClickFuntion(self, self.onWarClick);
	self.btnRank:addClickFuntion(self, self.onRankClick);

	self:addLuaEvent("CHAOS_COPY_INFO", self, self.updateServerInfo);
	self:addLuaEvent("CHAOS_COPY_TWEEN", self, self.updateStageInfo);
	self:addLuaEvent("CHAOS_COPY_FIGHT", self, self.onFightClick);
	Lua_ProxyManager.getProxy("Lua_ChaosCopyProxy"):sHeroList();
	self:updateServerInfo();
end

function Lua_ChaosCopyWindow:dispose()
	if self.stageItem then
		TweenUtil.getInstance():stop(self.stageItem.mainContent);
	end
	Lua_CommonUtil.removeTimer(self, self.onPlayTweened);
	self:stopTimer();
	DataCenter.preLoadData:removeBySign("Lua_ChaosCopyLineupWindow", self, self.onSceneShow);
	if self.chapterArr then
		self.chapterArr:dispose();
		self.chapterArr:clear();
		self.chapterArr = nil;
	end
	if self.taskRedPoint then
		self.taskRedPoint:dispose();
		self.taskRedPoint = nil;
	end
	if self.stageItem then
		self.stageItem:dispose();
		self.stageItem = nil;
	end
	self:superCall("dispose");
end

function Lua_ChaosCopyWindow:onBackBtnClick()
	DataCenter.funcPathUtil:gotoFunction(1035, true);
end

function Lua_ChaosCopyWindow:updateServerInfo()
	if DataCenter.chaosCopyData.msg80243011 ~= nil then
		return;
	end
	self:updateStageInfo(false);

	local stageId = DataCenter.chaosCopyData.curStageId;
	local config = DataCenter.chaosCopyUtil:getStageConfig(stageId);
	local chapter = config.chapter;

	local dataLen = 5;
	local arr = Array();
	local value = config.layer % dataLen;
	value = value == 0 and dataLen or value;
	local lastNum = value - 1;
	local nextNum = dataLen - value;
	while lastNum > 0 do
		arr:add(chapter * 1000 + (config.layer - lastNum));
		lastNum = lastNum - 1;
	end
	arr:add(stageId);
	for i = 1, nextNum do
		arr:add(chapter * 1000 + (config.layer + i));
	end

	config = DataCenter.chaosCopyUtil:getStageConfig(arr[dataLen]);
	config = DataCenter.chaosCopyUtil:getStageConfig(config.next_id);
	local isEnd = config and config.chapter > chapter;

	local spaceW = 120;
	local maxValue = (dataLen - 1) * spaceW;
	value = (value - 1) * spaceW;
	self.chapterBar:setMaxValue(maxValue);
	self.chapterBar:setValue(value);

	local len = self.chapterArr:getSize();
	local maxLen = dataLen > len and dataLen or len;
	local item;
	for i = 1, maxLen do
		item = self.chapterArr[i];
		if i > dataLen then
			if item then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_ChaosCopyChapterItem.new(self.content);
				self.chapterArr:add(item);
			else
				item:setEnable(true);
			end
			item:setRectAnchor(1);
			item:setLocation(-234 + (i - 1) * spaceW, -160, 0);
			item:setData(arr[i], (isEnd and i == dataLen));
		end
	end

	self:updateHookInfo();
	self:startTimer();
	self:onTimer();
end

function Lua_ChaosCopyWindow:updateStageInfo(bShowTween)
	if self.stageItem == nil then
		self.stageItem = Lua_ChaosCopyStageItem.new(self.content);
		self.stageItem:setRectAnchor(1);
	end
	self.stageItem:setLocation(0, -733, 0);
	self.stageItem:setData();

	if bShowTween then
		if not self.bPlayTween then
			self.bPlayTween = true;
			self.tweenSetp = 1;
			self:playTween();
		end
	else
		self.stageItem:playEffect(false);
	end
end

function Lua_ChaosCopyWindow:playTween()
	TweenUtil.getInstance():stop(self.stageItem.mainContent);
	Lua_CommonUtil.removeTimer(self, self.onPlayTweened);

	if self.tweenSetp == 1 then
		TweenUtil.getInstance():addTweenTargetPos(self.stageItem.mainContent, 0.5, 0, -720, -733, 0);
		Lua_CommonUtil.delayCall(0.5, self, self.onPlayTweened);
	elseif self.tweenSetp == 2 then
		TweenUtil.getInstance():addTweenTargetPos(self.stageItem.mainContent, 0.5, 0, 0, -733, 0);
		Lua_CommonUtil.delayCall(0.4, self, self.onPlayTweened);
	elseif self.tweenSetp == 3 then
		Lua_CommonUtil.delayCall(0.2, self, self.onPlayTweened);
	end
end

function Lua_ChaosCopyWindow:onPlayTweened()
	if self.tweenSetp == 1 then
		self.stageItem:setLocation(720, -733, 0);
	elseif self.tweenSetp == 2 then
		self.stageItem:playEffect(true);
	elseif self.tweenSetp == 3 then
		self.bPlayTween = false;
		self:updateServerInfo();
	end

	self.tweenSetp = self.tweenSetp + 1;
	self:playTween();
end

function Lua_ChaosCopyWindow:updateHookInfo()
	local bValue = DataCenter.chaosCopyData.bShowHook;
	self.hookObject:SetActive(bValue);
	self.hookTime = DataCenter.chaosCopyData.hookTime;
	self.hookLimitSec = DataCenter.chaosCopyUtil.hookLimitSec;
end

function Lua_ChaosCopyWindow:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self:addTimer("Lua_ChaosCopyWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_ChaosCopyWindow:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_ChaosCopyWindow:onTimer()
	local second = DataCenter.chaosCopyData.endTime - DataCenter.roleData.serverTime;
	if second > 0 then
		self.timeText:setEnable(true);
		if DataCenter.chaosCopyData.seasonStatus == 1 then
			self.timeText.text = LanUtil.formateStr(796000, Lua_TimeTransform.transSeconds26(second));
		else
			self.timeText.text = LanUtil.formateStr(796001, Lua_TimeTransform.transSeconds26(second));
		end
	else
		self.timeText:setEnable(false);
	end

	if DataCenter.chaosCopyData.bShowHook then
		self.hookTime = DataCenter.chaosCopyData.hookTime;
		if self.hookTime >= self.hookLimitSec then
			self.hookTime = self.hookLimitSec;
			self.hookTimeText.text = LanUtil.formateStr(796006, Lua_TimeTransform.transSeconds6(self.hookTime));
		else
			self.hookTimeText.text = LanUtil.formateStr(796005, Lua_TimeTransform.transSeconds6(self.hookTime));
		end
	end
end

function Lua_ChaosCopyWindow:onHelpClick(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { posX = 180, posY = -240, des = 796002 });
end

function Lua_ChaosCopyWindow:onHookReceive(go)
	if self.hookTime <= 60 then
		OperateAlert.showLangValue(796011);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ChaosCopyProxy"):sReceiveHookReward();
end

function Lua_ChaosCopyWindow:onShopClick(go)
	DataCenter.funcPathUtil:gotoFunction(1200);
end

function Lua_ChaosCopyWindow:onSwordsClick(go)
	Lua_WindowUtil.openWin("Lua_ChaosCopySwordsWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_ChaosCopyWindow:onTaskClick(go)
	Lua_WindowUtil.openWin("Lua_ChaosCopyTaskWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_ChaosCopyWindow:onWarClick(go)
	DataCenter.funcPathUtil:gotoFunction(1199);
end

function Lua_ChaosCopyWindow:onRankClick(go)
	DataCenter.funcPathUtil:gotoFunction(1196);
end

function Lua_ChaosCopyWindow:onFightClick(data)
	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_CHAOS_COPY);
	DataCenter.preLoadData:preShowScene("Lua_ChaosCopyLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, data, sceneId, 0);
end

function Lua_ChaosCopyWindow:onSceneShow(param, mp, success)
	if success then
		Lua_WindowUtil.openWin("Lua_ChaosCopyLineupWindow", Lua_WinParam.ACTION_OPEN, param);
	end
end










Lua_ChaosCopyChapterItem = class("Lua_ChaosCopyChapterItem", Lua_DisplayObject)
function Lua_ChaosCopyChapterItem:ctor(p)
	self:superCall("ctor", p, "ChaosCopyChapterItem_skin");
end

function Lua_ChaosCopyChapterItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_ChaosCopyChapterItem:dispose()
	self:superCall("dispose");
end

function Lua_ChaosCopyChapterItem:setData(stageId, isEnd)
	local config = DataCenter.chaosCopyUtil:getStageConfig(stageId);
	self.nameText.text = config.stage_name;

	if isEnd then
		if stageId == DataCenter.chaosCopyData.curStageId then
			self.icon:setAltas("chaos_copy_atlas", "xui_hdxj_label_05");
		else
			self.icon:setAltas("chaos_copy_atlas", "xui_hdxj_label_04");
		end
	else
		if stageId == DataCenter.chaosCopyData.curStageId then
			self.icon:setAltas("chaos_copy_atlas", "xui_hdxj_label_03");
		else
			self.icon:setAltas("chaos_copy_atlas", "xui_hdxj_label_02");
		end
	end
	self.icon:resetSize();
end