Lua_ChaosCopySwordsSkillWindow = class("Lua_ChaosCopySwordsSkillWindow", Lua_Window)
function Lua_ChaosCopySwordsSkillWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ChaosCopySwordsSkillWindow";
	self.skinName = "ChaosCopySwordsSkillWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ChaosCopySwordsSkillWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.selectedDic = {};
	local skillList = DataCenter.chaosCopyData.swordsSkillList;
	if skillList then
		for i,v in ipairs(skillList) do
			self.selectedDic[v] = 1;
		end
	end

	local arr = DataCenter.chaosCopyUtil.swordsList;
	local config = DataCenter.chaosCopyUtil:getSwordSkillConfig(arr[1]);
	local skillId;
	for i,v in ipairs(config.skill_list) do
		if self.selectedDic[v] == 1 then
			skillId = v;
		end
	end
	skillId = skillId or config.skill_list[1];
	DataCenter.chaosCopyData.showSkillId = skillId;

	self.promptText:setLangValue(796016);

	self.skillItem = Lua_SkillIconItem.new(self.content);
	self.skillItem:setLocation(-206, 259, 0);

	self.textArea = Lua_TextArea.new(self.content, 435, 80);
	self.textArea:setLocation(103, 215, 0);

	self.itemList = Lua_DragList.new(self.content, 630, 540, Lua_AxisDefine.Vertical);
	self.itemList.customParam = self.selectedDic;
	self.itemList:setLocation(0, -103, 0);
	self.itemList:setListCell(Lua_ChaosCopySwordsSkillCell, 630, 135, 1);
	self.itemList:setArrayData(arr);
	self.itemList.canDrag = not self.itemList.isTheEnd;

	self:addLuaEvent("CHAOS_COPY_SWORDS_SKILL_SELECT", self, self.updateSelected);
	self:addLuaEvent("CHAOS_COPY_SWORDS_SKILL", self, self.updateServerInfo);
	self:updateShowInfo();

	self.btnSubmit:addClickFuntion(self, self.onSubmitClick);
end

function Lua_ChaosCopySwordsSkillWindow:dispose()
	if self.skillItem then
		self.skillItem:dispose();
		self.skillItem = nil;
	end
	if self.textArea then
		self.textArea:dispose();
		self.textArea = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self.selectedDic = nil;
	DataCenter.chaosCopyData.showSkillId = nil;
	self:superCall("dispose");
end

function Lua_ChaosCopySwordsSkillWindow:updateShowInfo()
	local skillId = DataCenter.chaosCopyData.showSkillId;
	local config = Lua_SkillConfigData.getConfigData(skillId);
	self.skillItem:setData(config);
	self.nameText.text = config.name;
	self.textArea:setText(config.des, 24, 1, 0, "726763");
end

function Lua_ChaosCopySwordsSkillWindow:updateSelected(skillId)
	DataCenter.chaosCopyData.showSkillId = skillId;
	self:updateShowInfo();
	self.itemList:updateShowList();
end

function Lua_ChaosCopySwordsSkillWindow:updateServerInfo()
	table.clear(self.selectedDic);
	local skillList = DataCenter.chaosCopyData.swordsSkillList;
	if skillList then
		for i,v in ipairs(skillList) do
			self.selectedDic[v] = 1;
		end
	end
	self.itemList:updateShowList();
end

function Lua_ChaosCopySwordsSkillWindow:onSubmitClick(go)
	Lua_ProxyManager.getProxy("Lua_ChaosCopyProxy"):sSetSwordsSkill(self.selectedDic);
end









Lua_ChaosCopySwordsSkillCell = class("Lua_ChaosCopySwordsSkillCell", Lua_ListCell)
function Lua_ChaosCopySwordsSkillCell:ctor(p)
	self:superCall("ctor", p, "ChaosCopySwordsSkillCell_skin");
end

function Lua_ChaosCopySwordsSkillCell:buildShowItem()
	self:superCall("buildShowItem");
	self.skillList = Array();
end

function Lua_ChaosCopySwordsSkillCell:dispose()
	if self.skillList then
		self.skillList:dispose();
		self.skillList:clear();
		self.skillList = nil;
	end
	self.selectedDic = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChaosCopySwordsSkillCell:setCustomParam(customParam)
	self.selectedDic = customParam;
end

function Lua_ChaosCopySwordsSkillCell:setData(data)
	self.data = DataCenter.chaosCopyUtil:getSwordSkillConfig(data);
	local swordsLv = DataCenter.chaosCopyData.swordsLv;
	if swordsLv >= self.data.level_limit then
		self.isUnlock = true;
		self.unlockText.colorStr = Lua_ColorDefine.transColorStr("479154");
	else
		self.isUnlock = false;
		self.unlockText.colorStr = Lua_ColorDefine.transColorStr("E54242");
	end
	self.unlockText.text = LanUtil.formateStr(796017, tostring(self.data.level_limit));

	self:updateData();
end

function Lua_ChaosCopySwordsSkillCell:updateData()
	local item;
	for i,v in ipairs(self.data.skill_list) do
		item = self.skillList[i];
		if item == nil then
			item = Lua_ChaosCopySwordsSkillItem.new(self.content);
			item:setClick(self, self.onSkillSelected);
			self.skillList:add(item);
		end
		item:setLocation(-110 + (i - 1) * 118, 0, 0);
		item:setData(v, self.isUnlock, self.selectedDic[v] == 1);
	end
end

function Lua_ChaosCopySwordsSkillCell:onSkillSelected(skillId, bSelected)
	for i,v in ipairs(self.data.skill_list) do
		self.selectedDic[v] = nil;
	end
	if bSelected and self.isUnlock then
		self.selectedDic[skillId] = 1;
	end
	Lua_MsgUtil.callFunc("CHAOS_COPY_SWORDS_SKILL_SELECT", skillId);
end










Lua_ChaosCopySwordsSkillItem = class("Lua_ChaosCopySwordsSkillItem", Lua_DisplayObject)
function Lua_ChaosCopySwordsSkillItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ChaosCopySwordsSkillItem:buildShowItem()
	self:superCall("buildShowItem");

	self.skillItem = Lua_SkillIconItem.new(self.content);
	self.skillItem:setCanClick(true, self, self.onClick);
end

function Lua_ChaosCopySwordsSkillItem:dispose()
	if self.skillItem then
		self.skillItem:dispose();
		self.skillItem = nil;
	end
	self.owner = nil;
	self.callBack = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChaosCopySwordsSkillItem:setClick(owner, callBack)
	self.owner = owner;
	self.callBack = callBack;
end

function Lua_ChaosCopySwordsSkillItem:setData(data, isUnlock, isSelected)
	self.data = data;

	self.skillItem:setSkillId(data);
	if isUnlock then
		if self.cbSelect == nil then
			self.cbSelect = UICreate.createCheckBox(self.content, nil, 30, -40, 0, 0);
			self.cbSelect:setScale(0.7, 0.7, 1);
			self.cbSelect:addBoxChange(self, self.onSelectChange);
		end
		self.cbSelect:setEnable(true);
		self.cbSelect.selected = isSelected;

		if self.maskBg then
			self.maskBg:setEnable(false);
			self.lockIcon:setEnable(false);
		end
	else
		if self.maskBg == nil then
			self.maskBg = UICreate.createUIAtlasImage(self.content, "common_altas_4", "xui_common_widget_038", 0, 0, 0, 0);
			self.lockIcon = UICreate.createUIAtlasImage(self.content, "hero_develop_altas", "xui_hb_tab_5", 0, 0, 0, 0);
		end
		self.maskBg:setEnable(true);
		self.lockIcon:setEnable(true);

		if self.cbSelect then
			self.cbSelect:setEnable(false);
		end
	end

	if data == DataCenter.chaosCopyData.showSkillId then
		if self.selectedImg == nil then
			self.selectedImg = UICreate.createUIAtlasImage(self.content, "common_altas_5", "xui_common_widget_017_a", 0, 0, 0, 0);
		end
		self.selectedImg:setEnable(true);
	else
		if self.selectedImg then
			self.selectedImg:setEnable(false);
		end
	end
end

function Lua_ChaosCopySwordsSkillItem:onClick(data)
	if self.owner and self.callBack then
		self.callBack(self.owner, self.data, true);
	end
end

function Lua_ChaosCopySwordsSkillItem:onSelectChange(bSelected)
	if self.owner and self.callBack then
		self.callBack(self.owner, self.data, bSelected);
	end
end