Lua_ChaosCopySwordsWindow = class("Lua_ChaosCopySwordsWindow", Lua_Window)
function Lua_ChaosCopySwordsWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ChaosCopySwordsWindow";
	self.skinName = "ChaosCopySwordsWindow_skin";
	self.isFullSizeWin = true;
	-- self.isSingleShowWin = true;
	self.showWinBg = true;
	self.winBgPath = "/images/chaos_copy/xui_hdxj_bg_02.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_ChaosCopySwordsWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.winBg.anchorValue = 4;
	self.winBg.pivotValue = 4;

	self.moneyList = Array();
	self.swordList = Array();
	self.bgEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_hdxj_jj", "ui_hdxj_jj", 0, 0);

	self.btnHelp:addClickFuntion(self, self.onHelpClick);
	self.btnAttr:addClickFuntion(self, self.onAttrClick);
	self.btnSkill:addClickFuntion(self, self.onSkillClick);
	self.btnReset:addClickFuntion(self, self.onResetClick);

	self:addLuaEvent("CHAOS_COPY_SWORDS_INFO", self, self.updateServerInfo);
	self:updateShowInfo();
	Lua_ProxyManager.getProxy("Lua_ChaosCopyProxy"):sSwordsInfo();
end

function Lua_ChaosCopySwordsWindow:dispose()
	if self.moneyList then
		self.moneyList:dispose();
		self.moneyList:clear();
		self.moneyList = nil;
	end
	if self.swordList then
		self.swordList:dispose();
		self.swordList:clear();
		self.swordList = nil;
	end
	if self.bgEff then
		self.bgEff:dispose();
		self.bgEff = nil;
	end
	self:superCall("dispose");
end

function Lua_ChaosCopySwordsWindow:updateShowInfo()
	local list = {201000001, 201000002};
	local dataLen = #list;
	local len = self.moneyList:getSize();
	local maxLen = dataLen > len and dataLen or len;
	local item;
	for i = 1, maxLen do
		item = self.moneyList[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_MoneyItem.new(self.content);
				self.moneyList:add(item);
			else
				item:setEnable(true);
			end
			item:setRectAnchor(1);
			item:setLocation(249 - (i - 1) * 190, -26, 0);
			item:setCanClick(true);
			item:setMoney(list[i]);
		end
	end

	local arr = DataCenter.chaosCopyUtil.swordsList;
	dataLen = arr:getSize();
	len = self.swordList:getSize();
	maxLen = dataLen > len and dataLen or len;
	for i = 1, maxLen do
		item = self.swordList[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_ChaosCopySwordItem.new(self.content);
				self.swordList:add(item);
			else
				item:setEnable(true);
			end
			item:setData(arr[i]);
		end
	end
end

function Lua_ChaosCopySwordsWindow:updateServerInfo()
	local swordsLv = DataCenter.chaosCopyData.swordsLv;
	self.nameText.text = LanUtil.formateStr(796014, tostring(swordsLv));
	self.btnReset:setEnable(swordsLv > 0);
	for i = 1, self.swordList:getSize() do
		self.swordList[i]:updateData();
	end
end

function Lua_ChaosCopySwordsWindow:onHelpClick(go)
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, { posX = -165, posY = -240, des = 796013 });
end

function Lua_ChaosCopySwordsWindow:onAttrClick(go)
	Lua_WindowUtil.openWin("Lua_ChaosCopySwordsAttrWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_ChaosCopySwordsWindow:onSkillClick(go)
	Lua_WindowUtil.openWin("Lua_ChaosCopySwordsSkillWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_ChaosCopySwordsWindow:onResetClick(go)
	if (DataCenter.chaosCopyData.swordsResetTime - DataCenter.roleData.serverTime) > 0 then
		OperateAlert.showLangValue(796019);
		return;
	end

	local str = LanUtil.formateStr(796020, tostring(DataCenter.chaosCopyUtil.swordsResetCd));
    local tipData = { des = str, btnType = 1, owner = self, sureFun = self.onReset };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_ChaosCopySwordsWindow:onReset()
	Lua_ProxyManager.getProxy("Lua_ChaosCopyProxy"):sSwordsReset();
end










Lua_ChaosCopySwordItem = class("Lua_ChaosCopySwordItem", Lua_DisplayObject)
function Lua_ChaosCopySwordItem:ctor(p)
	self:superCall("ctor", p, "ChaosCopySwordItem_skin");
end

function Lua_ChaosCopySwordItem:buildShowItem()
	self:superCall("buildShowItem");
	self.icon:addClickFuntion(self, self.onClick);
end

function Lua_ChaosCopySwordItem:dispose()
	self:stopTween();
	self:superCall("dispose");
end

function Lua_ChaosCopySwordItem:setData(swordId)
	self.swordId = swordId;
	
	local config = DataCenter.chaosCopyUtil:getSwordSkillConfig(swordId);
	self.showX = config.pos[1] or 0;
	self.showY = config.pos[2] or 0;
	self.nameText.text = config.name;
	self.icon:setAltas("chaos_copy_atlas", config.sprite);

	self:updateData();
	self:stopTween();
	self:startTween();
end

function Lua_ChaosCopySwordItem:updateData()
	local level = DataCenter.chaosCopyData:getSwordLevel(self.swordId);
	self.levelText.text = LanUtil.formateStr(796015, tostring(level));
end

function Lua_ChaosCopySwordItem:startTween()
	if self.bTimer ~= true then
		self.bTimer = true;
		self.startTime = getTime();
		self.tweenValue = string.format("%.2f", LuaUtil.randomTriangle(1, 3));
		self:addTimer("Lua_ChaosCopySwordItem", 0.01, self, self.onTween, nil, -1);
	end
end

function Lua_ChaosCopySwordItem:stopTween()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTween);
	end
end

function Lua_ChaosCopySwordItem:onTween()
	local pt = (getTime() - self.startTime) * self.tweenValue;
	LuaUtil.setObjPos(self.mainContent, self.showX, self.showY + Mathf.Sin(pt) * 5, 0);
end

function Lua_ChaosCopySwordItem:onClick(go)
	Lua_WindowUtil.openWin("Lua_ChaosCopySwordUpgradeWindow", Lua_WinParam.ACTION_OPEN, self.swordId);
end