Lua_ChaosCopyTaskWindow = class("Lua_ChaosCopyTaskWindow", Lua_Window)
function Lua_ChaosCopyTaskWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ChaosCopyTaskWindow";
	self.skinName = "ChaosCopyTaskWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ChaosCopyTaskWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.taskArr = Array();
	self:addLuaEvent("CHAOS_COPY_TASK_INFO", self, self.updateTaskList);
	self:addLuaEvent("CHAOS_COPY_TASK_SINGLE", self, self.updateSingleTask);
	self:addLuaEvent("CHAOS_COPY_TASK_REVEIVE", self, self.onReceiveReward);

	self.taskList = Lua_DragList.new(self.content, 628, 900, Lua_AxisDefine.Vertical);
	self.taskList:setLocation(0, -38, 0);
	self.taskList:setListCell(Lua_ChaosCopyTaskItem, 628, 143, 1);
	self.taskList:setCellSpacing(0, 5);
	
	local arr = Array();
	arr:add({ textStr = 796022, redPointId = Lua_RedPointList.ChaosCopy_Task_Daily });
	arr:add({ textStr = 796023, redPointId = Lua_RedPointList.ChaosCopy_Task_Season });

	self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.btnList:setSiblingIndex(0);
	self.btnList:setRectPivot(3);
	self.btnList:setLocation(-330, -570, 0);
	self.btnList:setButtonStyle("common_altas_1", "xui_common_tab_002", "xui_common_tab_001", 133, 77);
	self.btnList:setButtonText(0, 10, "7A6A5F", "8F5123", 28, 28, Lua_MyUISettings.huakangFontName);
	self.btnList:setRedPoint(56, 25);
	self.btnList:setButtonItem(135, 77);
	self.btnList:setClickCallBack(self, self.onBtnClick);
	self.btnList:setData(arr);
	self.btnList:setSelected(1);
end

function Lua_ChaosCopyTaskWindow:dispose()
	if self.taskList then
		self.taskList:dispose();
		self.taskList = nil;
	end
	if self.btnList then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.taskArr then
		self.taskArr:clear();
		self.taskArr = nil;
	end
	self:superCall("dispose");
end

function Lua_ChaosCopyTaskWindow:onBtnClick(index, data)
	Lua_ProxyManager.getProxy("Lua_ChaosCopyProxy"):sTaskInfo(index);
end

function Lua_ChaosCopyTaskWindow:updateTaskList(msg)
	self.taskType = msg.task_type;
	local dataLen = #msg.task;
	local len = self.taskArr:getSize();
	local num = len - dataLen;
	while (num > 0) do
		self.taskArr:remove();
		num = num - 1;
	end
	for i = 1, dataLen do
		if i > len then
			self.taskArr:add(msg.task[i]);
		else
			self.taskArr[i] = msg.task[i];
		end
	end
	self.taskArr:sortf(self, self.onTaskSort);

	self.taskList:setArrayData(self.taskArr);
	self.taskList:moveToIndex(1, true);
end

function Lua_ChaosCopyTaskWindow:updateSingleTask(msg)
	local len = self.taskArr:getSize();
	local state = false;
	for i = 1, len do
		if self.taskArr[i].key == msg.task.key then
			self.taskArr[i] = msg.task;
		end
		if self.taskArr[i].ex_value == 1 then
			state = true;
		end
	end
	if self.taskType == 1 then
		DataCenter.redPointData:updateRedPointState(Lua_RedPointList.ChaosCopy_Task_Daily, state);
	elseif self.taskType == 2 then
		DataCenter.redPointData:updateRedPointState(Lua_RedPointList.ChaosCopy_Task_Season, state);
	end
	self.taskArr:sortf(self, self.onTaskSort);

	self.taskList:setArrayData(self.taskArr);
end

function Lua_ChaosCopyTaskWindow:onTaskSort(a, b)
	if a.ex_value == b.ex_value then
		if a.key > b.key then
			return false;
		end
	elseif a.ex_value == 2 and b.ex_value ~= 2 then
		return false;
	elseif a.ex_value ~= 1 and b.ex_value == 1 then
		return false;
	end
	return true;
end

function Lua_ChaosCopyTaskWindow:onReceiveReward(taskId)
	Lua_ProxyManager.getProxy("Lua_ChaosCopyProxy"):sReceiveTaskReward(self.taskType, taskId);
end










Lua_ChaosCopyTaskItem = class("Lua_ChaosCopyTaskItem", Lua_ListCell)
function Lua_ChaosCopyTaskItem:ctor(p)
	self:superCall("ctor", p, "ChaosCopyTaskItem_skin");
end

function Lua_ChaosCopyTaskItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_ItemIconList.new(self.content);
	self.rewardList:setLocation(-240, -12, 0);
	self.rewardList.pivot = 1;
	self.rewardList.scaleVal = 0.7;

	self.btnSubmit:addClickFuntion(self, self.onSubmitClick);
end

function Lua_ChaosCopyTaskItem:dispose()
	if self.rewardList then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChaosCopyTaskItem:setData(data)
	self.data = data;

	local config = DataCenter.chaosCopyUtil:getTaskConfig(data.key);
	self.titleText.text = config.desc;
	self.rewardList:setArrayData(config.task_reward);

	if data.ex_value == 2 then
		self.progressBar:setEnable(false);
		self.btnSubmit:setEnable(false);
		self.stateIcon:setEnable(true);
	else
		self.progressBar:setEnable(true);
		self.progressBar:setMaxValue(config.task_progress);
		self.progressBar:setValue(data.value);
		self.progressBar:setText(LanUtil.formateStr(10044, tostring(data.value), tostring(config.task_progress)));

		self.btnSubmit:setEnable(true);
		if data.ex_value == 1 then
			self.btnSubmit:setStyle(1);
			self.btnSubmit:setLangValue(796025);
			self.btnSubmit:setMouseEnable(true);
		else
			self.btnSubmit:setStyle(3);
			self.btnSubmit:setLangValue(796024);
			self.btnSubmit:setMouseEnable(false);
		end
		self.stateIcon:setEnable(false);
	end
end

function Lua_ChaosCopyTaskItem:onPressClick()
	self.rewardList:onBoundClick();
end

function Lua_ChaosCopyTaskItem:onSubmitClick(go)
	Lua_MsgUtil.callFunc("CHAOS_COPY_TASK_REVEIVE", self.data.key);
end